@@ -34,12 +34,16 @@ void initRank(int n, int **Rank, int *xrank, int *yrank, int *i_perm);
 void initRank_bcor(int n, int **Rank, int *xrank, int *yrank);
 void quicksort(double *a, int *idx, int l, int u);
 void quicksort2(double *a, double *b, int *idx, int l, int u);
+void rank_matrix_3d(double ***Dx, int n, int k, int ***Rx);
+void quick_rank(double *x, int *r, int n);
 double **alloc_matrix(int r, int c);
 double ***alloc_3d_matrix(int r, int c, int h);
 int **alloc_int_matrix(int r, int c);
+int ***alloc_3d_int_matrix(int r, int c, int h);
 void free_matrix(double **matrix, int r, int c);
 void free_3d_matrix(double ***arr3D, int r, int c);
 void free_int_matrix(int **matrix, int r, int c);
+void free_3d_int_matrix(int ***arr3D, int r, int c);
 void vector2matrix(double *x, double **y, int N, int d, int isroworder);
 void vector_2_3dmatrix(double *x, double ***y, int r, int c, int h, int isroworder);
 void Euclidean_distance(double *x, double **Dx, int n, int d);
@@ -52,8 +56,6 @@ void resample(int *i_perm, int *i_perm_inv, int *n);
 void resample_matrix(int **i_perm, int *r, int *c);
 void resample2(int *i_perm, int *n);
 void resample3(int *i_perm, int *i_perm_tmp, int n, int *n1);
-int random_index_thread_wrap(int i);
-void resample3_thread(int *permuted_arr, int *i_perm, int *i_perm_tmp, int n, int *n1);
 void ranksort(int *n, int *zrank, double *z, int *zidx);
 
 
